//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/MasksQModel.h
//! @brief     Defines class MasksQModel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MASK_MASKSQMODEL_H
#define BORNAGAIN_GUI_MODEL_MASK_MASKSQMODEL_H

#include <QAbstractListModel>
#include <QModelIndex>
#include <QVariant>

class MaskItem;
class MasksSet;
class OverlayItem;

//! Provides interfaces to a MasksSet, allowing its contents to be displayed and modified
//! using the Qt mechanisms.

class MasksQModel : public QAbstractListModel {
public:
    MasksQModel(MasksSet* set);
    ~MasksQModel();

    int rowCount(const QModelIndex&) const override;
    QVariant data(const QModelIndex& index, int role) const override;

    void clear();
    void deleteItem();
    QModelIndex pushItem(MaskItem*);

    MasksSet* set() { return m_masks; }
    const MasksSet* set() const { return m_masks; }

private:
    MasksSet* m_masks;
};

#endif // BORNAGAIN_GUI_MODEL_MASK_MASKSQMODEL_H
