//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Modelview/SetView.cpp
//! @brief     Implements class SetView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Modelview/SetView.h"
#include "GUI/Model/Type/SetWithModel.h"
#include "GUI/View/Widget/ListItemDelegate.h"

SetView::SetView(AbstractSetModel* set, int minimum_width, QSizePolicy policy)
{
    setMinimumWidth(minimum_width);
    setSizePolicy(policy);
    setSelectionMode(QAbstractItemView::NoSelection);
    setItemDelegate(new ListItemDelegate(this));
    setCurrentIndex({}); // make "current" invalid, hence invisible
    setSet(set);
}

void SetView::setSet(AbstractSetModel* set)
{
    setModel(set->model());
    disconnect(this, &QListView::clicked, nullptr, nullptr);
    connect(this, &QListView::clicked, [this, set](const QModelIndex& qi) {
        set->setCurrentIndex(qi.row());
        this->setCurrentIndex({}); // keep "current" invalid, hence invisible
    });
}
