//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Setup/MasksPanel.h
//! @brief     Defines class MasksPanel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SETUP_MASKSPANEL_H
#define BORNAGAIN_GUI_VIEW_SETUP_MASKSPANEL_H

#include <QFormLayout>
#include <QListView>
#include <QWidget>
#include <functional>

class Data2DItem;
class MaskItem;
class MasksQModel;

//! Panel with list of masks and parameter editor for one selected mask.

class MasksPanel : public QWidget {
    Q_OBJECT
public:
    MasksPanel();

    QSize sizeHint() const override;
    QSize minimumSizeHint() const override;

    void updateMasksPanel(MasksQModel* masks_qmodel);

private:
    //! Set the current mask and creates the UI to edit the mask's properties
    void setCurrentMaskItem(MaskItem* maskItem);

    //! Add a checkbox to edit a mask's boolean value
    void addMaskCheckBox(const QString& title, std::function<bool()> getter,
                         std::function<void(bool)> setter);

    QListView* m_qlistview;
    MasksQModel* m_qlistmodel;
    QFormLayout* m_editor_layout;
    MaskItem* m_current_mask_item; //!< the mask item whose properties shall be edited
    bool m_keep_selection = false;
};

#endif // BORNAGAIN_GUI_VIEW_SETUP_MASKSPANEL_H
